"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var base64 = require("base64-js");
var text_encoder_lite_module_1 = require("text-encoder-lite-module");
var WebSocketWrapper = /** @class */ (function () {
    function WebSocketWrapper(url) {
        this.url = url;
        this.textEncoder = new text_encoder_lite_module_1.TextEncoderLite();
        this.textDecoder = new text_encoder_lite_module_1.TextDecoderLite();
    }
    WebSocketWrapper.prototype.connect = function (receive, emit) {
        var _this = this;
        this.wsClient = new WebSocket(this.url, ['base64']);
        var promise = new Promise(function (resolve, reject) {
            _this.deferred = { resolve: resolve, reject: reject };
        });
        this.wsClient.onmessage = function (e) {
            if (_this.deferred) {
                _this.deferred.resolve();
                _this.deferred = undefined;
            }
            receive(_this.textDecoder.decode(base64.toByteArray(e.data)));
        };
        this.wsClient.onerror = function (err) {
            if (_this.deferred) {
                _this.deferred.reject(err);
                _this.deferred = undefined;
            }
            if (emit) {
                emit('socket-error', err);
            }
        };
        this.wsClient.onclose = function (event) {
            if (_this.deferred) {
                _this.deferred.reject(event);
                _this.deferred = undefined;
            }
            if (emit) {
                emit('socket-end', event);
            }
        };
        return promise;
    };
    WebSocketWrapper.prototype.send = function (msg) {
        this.wsClient.send(base64.fromByteArray(this.textEncoder.encode(msg)));
    };
    WebSocketWrapper.prototype.disconnect = function () {
        this.wsClient.close();
    };
    return WebSocketWrapper;
}());
exports.WebSocketWrapper = WebSocketWrapper;
//# sourceMappingURL=socketWrapper.js.map